@@ -35,7 +35,6 @@ require 'fog/ecloud'
 require 'fog/glesys'
 require 'fog/go_grid'
 require 'fog/google'
-require 'fog/hp'
 require 'fog/ibm'
 require 'fog/internet_archive'
 require 'fog/joyent'
@@ -65,3 +64,4 @@ require 'fog/zerigo'
 require 'fog/cloudsigma'
 require 'fog/openvz'
 require 'fog/opennebula'
+require 'fog/aliyun'
