@@ -67,7 +67,6 @@ require 'fog/bin/ecloud'
 require 'fog/bin/glesys'
 require 'fog/bin/go_grid'
 require 'fog/bin/google'
-require 'fog/bin/hp'
 require 'fog/bin/ibm'
 require 'fog/bin/internet_archive'
 require 'fog/bin/joyent'
@@ -97,3 +96,4 @@ require 'fog/bin/zerigo'
 require 'fog/bin/cloudsigma'
 require 'fog/bin/openvz'
 require 'fog/bin/opennebula'
+require 'fog/bin/aliyun'
