@@ -4,7 +4,6 @@ require 'fog/json'
 module Fog
   module DigitalOcean
     extend Fog::Provider
-    service(:compute, 'Compute')
+    service(:compute_v2, 'Compute')
   end
 end
-
