@@ -5,7 +5,8 @@ module Fog
         def get_machine_snapshot(machine_id, snapshot_name)
           request(
             :path => "/my/machines/#{machine_id}/snapshots/#{snapshot_name}",
-            :method => "GET"
+            :method => "GET",
+            :idempotent => true
           )
         end
       end
