@@ -30,6 +30,7 @@ module Fog
         PORT        = 443
         SCHEME      = 'https'
         API_VERSION = '5.1'
+        OMIT_DEFAULT_PORT = true
       end
 
       class ServiceError < Fog::VcloudDirector::Errors::ServiceError; end
@@ -54,6 +55,10 @@ module Fog
       model      :organization
       collection :organizations
       model      :catalog_item
+      collection :vapp_templates
+      model      :vapp_template
+      collection :template_vms
+      model      :template_vm
       collection :catalog_items
       model      :custom_field
       collection :custom_fields
@@ -158,6 +163,8 @@ module Fog
       request :get_supported_versions
       request :get_task
       request :get_task_list
+      request :get_template_vm
+      request :get_template_vms
       request :get_thumbnail
       request :get_users_from_query
       request :get_vapp
@@ -209,6 +216,8 @@ module Fog
       request :post_create_catalog_item
       request :post_create_org_vdc_network
       request :post_deploy_vapp
+      request :post_compose_vapp
+      request :post_recompose_vapp
       request :post_detach_disk
       request :post_disable_nested_hv
       request :post_disable_vapp_template_download
@@ -337,6 +346,7 @@ module Fog
           @vcloud_director_password = options[:vcloud_director_password]
           @vcloud_director_username = options[:vcloud_director_username]
           @connection_options = options[:connection_options] || {}
+          @connection_options[:omit_default_port] = Fog::Compute::VcloudDirector::Defaults::OMIT_DEFAULT_PORT unless @connection_options[:omit_default_port]
           @host       = options[:vcloud_director_host]
           @path       = options[:path]        || Fog::Compute::VcloudDirector::Defaults::PATH
           @persistent = options[:persistent]  || false
