@@ -4,12 +4,18 @@ require 'fog/vcloud_director/models/compute/vdc'
 module Fog
   module Compute
     class VcloudDirector
-
       class Vdcs < Collection
+
+        include Fog::VcloudDirector::Query
+
         model Fog::Compute::VcloudDirector::Vdc
 
         attribute :organization
 
+        def query_type
+          "orgVdc"
+        end
+
         private
 
         def get_by_id(item_id)
@@ -25,7 +31,6 @@ module Fog
           items.each{|item| service.add_id_from_href!(item) }
           items
         end
-
       end
     end
   end
