@@ -28,6 +28,7 @@ if Fog.mock?
     :clodo_username                   => 'clodo_username',
     :digitalocean_api_key             => 'digitalocean_api_key',
     :digitalocean_client_id           => 'digitalocean_client_id',
+    :digitalocean_token               => 'digitalocean_token',
     :dnsimple_email                   => 'dnsimple_email',
     :dnsimple_password                => 'dnsimple_password',
     :dnsmadeeasy_api_key              => 'dnsmadeeasy_api_key',
@@ -84,10 +85,6 @@ if Fog.mock?
     :dynect_customer                  => 'dynect_customer',
     :dynect_username                  => 'dynect_username',
     :dynect_password                  => 'dynect_password',
-    :vsphere_server                   => 'virtualcenter.lan',
-    :vsphere_username                 => 'apiuser',
-    :vsphere_password                 => 'apipassword',
-    :vsphere_expected_pubkey_hash     => 'abcdef1234567890',
     :cloudsigma_username              => 'csuname',
     :cloudsigma_password              => 'cspass',
     :docker_username                  => 'docker-fan',
